@@ -479,9 +479,10 @@ class StickProtocol():
             user.save()
             device = self.Device.objects.filter(user=user, deviceId=data['deviceId']).first()
             if not device:
-                self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'], chatId=uuid.uuid4())
+                device = self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'], chatId=uuid.uuid4())
             else:
                 device.chatId = uuid.uuid4()
+            bundle['oneTimeId'] = device.chatId
             return {"bundle": bundle, "verify": True}
         else:
             return {"verify": False}
